% Script-File weibulltestBspFahrten.m
%
% Aufruf:   weibulltestBspFahrten
%
% Beispiel: Berechnung der Dichte der Weibull-Verteilung
% fr die Parameter einer Messung von Gebirgsfahrten.
% Die Verteilung wird grafisch dargestellt Mittelwert und Varianz
% der im Beispiel definierten Zufallsvariablen Y werden berechnet.
%
% Autor: Prof. Dr. Ottmar Beucher
%        FH Karlsruhe
% Version: 1.01
% Datum: 28.08.2002

x=(0:0.001:100);          % Wertebereich von Y
b = 0.444;  T=0.767;      % Parameter der Weibull-Verteilung

                          % Verteilungsdichte der Lognormal-Verteilung
a = 1/(T^b);              % Anpassung der Parameter auf die MATLAB-Definition
                          % Berechnung Weibull-Verteilungsdichte
pdfwb = weibpdfB(x, a, b);   
                          % grafische Darstellung
plot(x, pdfwb,'r-','LineWidth',4);
set(gca, 'FontSize', 14);
xlabel('Prozentsatz Gebirgsfahrten (x)', 'FontSize', 14);
ylabel('f_{T,b}(x)', 'FontSize', 14);
axis([0,100,0,0.4])

set(gca, 'XTick', (0:10:100));
xtn = ['  0'; ' 10'; ' 20'; ' 30'; ' 40'; ' 50';' 60'; ' 70'; ' 80'; ' 90'; '100'];
set(gca, 'YTick', (0:0.05:0.4));
ytn = ['   0'; '0.05'; ' 0.1'; '0.15'; ' 0.2'; '0.25'; ' 0.3'; '0.35'; ' 0.4'];
set(gca, 'YTickLabel', ytn)

                          % Berechnung von Erwartungswert und
                          % Varianz
[EW, Var] = weibstatB(a, b)
                          % Berechnung des Medianwertes
u_50 = weibinvB(0.5,a, b)                     
                          % Berechnung des Modalwertes
[m,i] = max(pdfwb); 
m=x(i)


